==> offhandhotbar-1.0.4%2Bmc1.21.8-sources.jar: archives/tater/offhandhotbar/MidnightLibExtras.java <==
package archives.tater.offhandhotbar;

import com.google.common.collect.Lists;
import eu.midnightdust.lib.config.MidnightConfig;
import net.minecraft.class_124;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_339;
import net.minecraft.class_3675;
import net.minecraft.class_4185;
import net.minecraft.class_5250;
import net.minecraft.class_7919;
import net.minecraft.class_8662;
import org.jetbrains.annotations.Nullable;
import org.lwjgl.glfw.GLFW;

/**
 * Source: <a href="https://github.com/TeamMidnightDust/MidnightLib/blob/architectury-1.21.4/test-fabric/src/main/java/eu/midnightdust/fabric/example/MidnightLibExtras.java">MidnightLibExtras</a>
 */
public class MidnightLibExtras {
    public static class KeybindButton extends class_4185 {
        public static class_4185 focusedButton;

        public static void add(class_304 binding, MidnightConfig.MidnightConfigListWidget list, MidnightConfig.MidnightConfigScreen screen) {
            KeybindButton editButton = new KeybindButton(screen.field_22789 - 185, 0, 150, 20, binding);
            class_8662 resetButton = class_8662.method_52723(class_2561.method_43471("controls.reset"), (button -> {
                binding.method_1422(binding.method_1429());
                screen.updateList();
            }), true).method_52727(class_2960.method_60655("midnightlib","icon/reset"), 12, 12).method_52726(20, 20).method_52724();
            resetButton.method_48229(screen.field_22789 - 205 + 150 + 25, 0);
            editButton.resetButton = resetButton;
            editButton.updateMessage(false);
            MidnightConfig.EntryInfo info = new MidnightConfig.EntryInfo(null, screen.modid);

            list.addButton(Lists.newArrayList(editButton, resetButton), class_2561.method_43471(binding.method_1431()), info);
        }

        private final class_304 binding;
        private @Nullable class_339 resetButton;
        public KeybindButton(int x, int y, int width, int height, class_304 binding) {
            super(x, y, width, height, binding.method_16007(), (button) -> {
                ((KeybindButton) button).updateMessage(true);
                focusedButton = button;
            }, (textSupplier) -> binding.method_1415() ? class_2561.method_43469("narrator.controls.unbound", binding.method_1431()) : class_2561.method_43469("narrator.controls.bound", binding.method_1431(), textSupplier.get()));
            this.binding = binding;
            updateMessage(false);
        }
        @Override
        public boolean method_25404(int keyCode, int scanCode, int modifiers) {
            if (focusedButton == this) {
                if (keyCode == GLFW.GLFW_KEY_ESCAPE) {
                    this.binding.method_1422(class_3675.field_16237);
                } else {
                    this.binding.method_1422(class_3675.method_15985(keyCode, scanCode));
                }
                updateMessage(false);

                focusedButton = null;
                return true;
            }
            return super.method_25404(keyCode, scanCode, modifiers);
        }

        public void updateMessage(boolean focused) {
            boolean hasConflicts = false;
            class_5250 conflictingBindings = class_2561.method_43473();
            if (focused) this.method_25355(class_2561.method_43470("> ").method_10852(this.binding.method_16007().method_27661().method_27695(class_124.field_1068, class_124.field_1073)).method_27693(" <").method_27692(class_124.field_1054));
            else {
                this.method_25355(this.binding.method_16007());

                if (!this.binding.method_1415()) {
                    for(class_304 keyBinding : class_310.method_1551().field_1690.field_1839) {
                        if (keyBinding != this.binding && this.binding.method_1435(keyBinding)) {
                            if (hasConflicts) conflictingBindings.method_27693(", ");

                            hasConflicts = true;
                            conflictingBindings.method_10852(class_2561.method_43471(keyBinding.method_1431()));
                        }
                    }
                }
            }

            if (this.resetButton != null) this.resetButton.field_22763 = !this.binding.method_1427();

            if (hasConflicts) {
                this.method_25355(class_2561.method_43470("[ ").method_10852(this.method_25369().method_27661().method_27692(class_124.field_1068)).method_27693(" ]").method_27692(class_124.field_1061));
                this.method_47400(class_7919.method_47407(class_2561.method_43469("controls.keybinds.duplicateKeybinds", conflictingBindings)));
            } else {
                this.method_47400(null);
            }
        }
    }
}

==> offhandhotbar-1.1.0%2Bmc1.21.9-sources.jar: archives/tater/offhandhotbar/MidnightLibExtras.java <==
package archives.tater.offhandhotbar;

import com.google.common.collect.Lists;
import eu.midnightdust.lib.config.EntryInfo;
import eu.midnightdust.lib.config.MidnightConfigListWidget;
import eu.midnightdust.lib.config.MidnightConfigScreen;
import net.minecraft.class_11908;
import net.minecraft.class_124;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_339;
import net.minecraft.class_3675;
import net.minecraft.class_4185;
import net.minecraft.class_5250;
import net.minecraft.class_7919;
import net.minecraft.class_8662;
import org.jetbrains.annotations.Nullable;
import org.lwjgl.glfw.GLFW;

/**
 * Source: <a href="https://github.com/TeamMidnightDust/MidnightLib/blob/architectury-1.21.4/test-fabric/src/main/java/eu/midnightdust/fabric/example/MidnightLibExtras.java">MidnightLibExtras</a>
 */
public class MidnightLibExtras {
    public static class KeybindButton extends class_4185 {
        public static class_4185 focusedButton;

        public static void add(class_304 binding, MidnightConfigListWidget list, MidnightConfigScreen screen) {
            KeybindButton editButton = new KeybindButton(screen.field_22789 - 185, 0, 150, 20, binding);
            class_8662 resetButton = class_8662.method_52723(class_2561.method_43471("controls.reset"), (button -> {
                binding.method_1422(binding.method_1429());
                screen.updateList();
            }), true).method_52727(class_2960.method_60655("midnightlib","icon/reset"), 12, 12).method_52726(20, 20).method_52724();
            resetButton.method_48229(screen.field_22789 - 205 + 150 + 25, 0);
            editButton.resetButton = resetButton;
            editButton.updateMessage(false);
            EntryInfo info = new EntryInfo(null, screen.modid);

            list.addButton(Lists.newArrayList(editButton, resetButton), class_2561.method_43471(binding.method_1431()), info);
        }

        private final class_304 binding;
        private @Nullable class_339 resetButton;
        public KeybindButton(int x, int y, int width, int height, class_304 binding) {
            super(x, y, width, height, binding.method_16007(), (button) -> {
                ((KeybindButton) button).updateMessage(true);
                focusedButton = button;
            }, (textSupplier) -> binding.method_1415() ? class_2561.method_43469("narrator.controls.unbound", binding.method_1431()) : class_2561.method_43469("narrator.controls.bound", binding.method_1431(), textSupplier.get()));
            this.binding = binding;
            updateMessage(false);
        }
        @Override
        public boolean method_25404(class_11908 input) {
            if (focusedButton == this) {
                if (input.comp_4795() == GLFW.GLFW_KEY_ESCAPE) {
                    this.binding.method_1422(class_3675.field_16237);
                } else {
                    this.binding.method_1422(class_3675.method_15985(input));
                }
                updateMessage(false);

                focusedButton = null;
                return true;
            }
            return super.method_25404(input);
        }

        public void updateMessage(boolean focused) {
            boolean hasConflicts = false;
            class_5250 conflictingBindings = class_2561.method_43473();
            if (focused) this.method_25355(class_2561.method_43470("> ").method_10852(this.binding.method_16007().method_27661().method_27695(class_124.field_1068, class_124.field_1073)).method_27693(" <").method_27692(class_124.field_1054));
            else {
                this.method_25355(this.binding.method_16007());

                if (!this.binding.method_1415()) {
                    for(class_304 keyBinding : class_310.method_1551().field_1690.field_1839) {
                        if (keyBinding != this.binding && this.binding.method_1435(keyBinding)) {
                            if (hasConflicts) conflictingBindings.method_27693(", ");

                            hasConflicts = true;
                            conflictingBindings.method_10852(class_2561.method_43471(keyBinding.method_1431()));
                        }
                    }
                }
            }

            if (this.resetButton != null) this.resetButton.field_22763 = !this.binding.method_1427();

            if (hasConflicts) {
                this.method_25355(class_2561.method_43470("[ ").method_10852(this.method_25369().method_27661().method_27692(class_124.field_1068)).method_27693(" ]").method_27692(class_124.field_1061));
                this.method_47400(class_7919.method_47407(class_2561.method_43469("controls.keybinds.duplicateKeybinds", conflictingBindings)));
            } else {
                this.method_47400(null);
            }
        }
    }
}
